@@ -4,7 +4,7 @@ from scrapy.crawler import CrawlerProcess
 from scrapy.utils.project import get_project_settings
 from multiprocessing import Process
 from .mi import calc
-from db_hj3415 import mongo2
+from db_hj3415 import mongo2, dbpath
 import datetime
 
 import logging
@@ -16,9 +16,6 @@ logger.addHandler(ch)
 logger.setLevel(logging.ERROR)
 
 
-MONGO_ADDR = 'mongodb://192.168.0.173:27017'
-
-
 def chcwd(func):
     # scrapy는 항상 프로젝트 내부에서 실행해야하기때문에 일시적으로 현재 실행경로를 변경한다.
     def wrapper(*args, **kwargs):
@@ -60,7 +57,7 @@ def mi():
 
     # calc 모듈을 이용해서 avg_per 과 yield_gap 을 계산하여 저장한다.
     print('*' * 25, f"Calculate and save avgper and yieldgap", '*' * 25)
-    client = mongo2.connect_mongo(MONGO_ADDR)
+    client = mongo2.connect_mongo(dbpath.load())
     mi_mongo2 = mongo2.MI(client, 'avgper')
     # mi_sqlite = sqlite.MI()
     today_str = datetime.datetime.today().strftime('%Y.%m.%d')
