@@ -1,7 +1,7 @@
 # reference from https://livedata.tistory.com/27?category=1026425 (scrapy pipeline usage)
 from . import items
-from db_hj3415 import mongo2
-from scraper_hj3415.db_path import MONGO_ADDR
+from db_hj3415 import mongo2, dbpath
+
 
 import logging
 logger = logging.getLogger(__name__)
@@ -13,7 +13,7 @@ logger.setLevel(logging.INFO)
 
 
 class C101Pipeline:
-    client = mongo2.connect_mongo(MONGO_ADDR)
+    client = mongo2.connect_mongo(dbpath.load())
     # c101에서 eps, bps, per, pbr을 수동으로 계산하여 입력하는 파이프라인
 
     def process_item(self, item, spider):
@@ -45,7 +45,7 @@ class C101Pipeline:
 
 
 class Mongo2Pipeline:
-    client = mongo2.connect_mongo(MONGO_ADDR)
+    client = mongo2.connect_mongo(dbpath.load())
 
     # 몽고 데이터 베이스에 저장하는 파이프라인
     def process_item(self, item, spider):
